==> haskell-xml-1.3.14-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-4CFkuDapbpFLOtwR0lZo9m
key: xml-1.3.14-4CFkuDapbpFLOtwR0lZo9m
license: BSD3
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types
abi: eb34efeb7de861c056c316aa1bf178a8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xml-1.3.14
hs-libraries: HSxml-1.3.14-4CFkuDapbpFLOtwR0lZo9m
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-1.3.14-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
key: xml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
license: BSD3
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types
abi: fedfcd8358368449c1a67792ce0a7f5d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xml-1.3.14
hs-libraries: HSxml-1.3.14-gmCpsUXEJ0Cd36ZPTskAU
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
